==> BSgenome.Scerevisiae.UCSC.sacCer2_1.3.17.tar.gz: BSgenome.Scerevisiae.UCSC.sacCer2/man/package.Rd <==
\name{Scerevisiae}
\docType{package}

\alias{BSgenome.Scerevisiae.UCSC.sacCer2-package}
\alias{BSgenome.Scerevisiae.UCSC.sacCer2}
\alias{Scerevisiae}


\title{Saccharomyces cerevisiae (Yeast) full genome (UCSC version sacCer2)}

\description{
  Saccharomyces cerevisiae (Yeast) full genome as provided by UCSC (sacCer2, June 2008) and stored in Biostrings objects.
}

\details{
  
}

\note{
  This BSgenome data package was made from the following source data files:
  \preformatted{
http://hgdownload.cse.ucsc.edu/goldenPath/sacCer2/bigZips/chromFa.tar.gz

  }
  See \code{?\link[BSgenome]{BSgenomeForge}} and the BSgenomeForge
  vignette (\code{vignette("BSgenomeForge")}) in the BSgenome software
  package for how to make a BSgenome data package.
}

\author{H. Pages}

\seealso{
  \link[BSgenome]{BSgenome-class},
  \link[Biostrings]{DNAString-class},
  \code{\link[BSgenome]{available.genomes}},
  \link[BSgenome]{BSgenomeForge}
}

\examples{
Scerevisiae
seqlengths(Scerevisiae)
Scerevisiae$chrI  # same as Scerevisiae[["chrI"]]

if ("AGAPS" \%in\% masknames(Scerevisiae)) {

  ## Check that the assembly gaps contain only Ns:
  checkOnlyNsInGaps <- function(seq)
  {
    ## Replace all masks by the inverted AGAPS mask
    masks(seq) <- gaps(masks(seq)["AGAPS"])
    unique_letters <- uniqueLetters(seq)
    if (any(unique_letters != "N"))
        stop("assembly gaps contain more than just Ns")
  }

  ## A message will be printed each time a sequence is removed
  ## from the cache:
  options(verbose=TRUE)

  for (seqname in seqnames(Scerevisiae)) {
    cat("Checking sequence", seqname, "... ")
    seq <- Scerevisiae[[seqname]]
    checkOnlyNsInGaps(seq)
    cat("OK\n")
  }
}

## See the GenomeSearching vignette in the BSgenome software
## package for some examples of genome-wide motif searching using
## Biostrings and the BSgenome data packages:
if (interactive())
    vignette("GenomeSearching", package="BSgenome")
}

\keyword{package}
\keyword{data}

==> BSgenome.Scerevisiae.UCSC.sacCer2_1.3.19.tar.gz: BSgenome.Scerevisiae.UCSC.sacCer2/man/package.Rd <==
\name{BSgenome.Scerevisiae.UCSC.sacCer2}
\docType{package}

\alias{BSgenome.Scerevisiae.UCSC.sacCer2-package}
\alias{BSgenome.Scerevisiae.UCSC.sacCer2}
\alias{Scerevisiae}

\title{Saccharomyces cerevisiae (Yeast) full genome (UCSC version sacCer2)}

\description{
  Saccharomyces cerevisiae (Yeast) full genome as provided by UCSC (sacCer2, June 2008) and stored in Biostrings objects.
}

\details{
  
}

\note{
  This BSgenome data package was made from the following source data files:
  \preformatted{
http://hgdownload.cse.ucsc.edu/goldenPath/sacCer2/bigZips/chromFa.tar.gz

  }
  See \code{?\link[BSgenome]{BSgenomeForge}} and the BSgenomeForge
  vignette (\code{vignette("BSgenomeForge")}) in the BSgenome software
  package for how to make a BSgenome data package.
}

\author{The Bioconductor Dev Team}

\seealso{
  \link[BSgenome]{BSgenome-class},
  \link[Biostrings]{DNAString-class},
  \code{\link[BSgenome]{available.genomes}},
  \link[BSgenome]{BSgenomeForge}
}

\examples{
BSgenome.Scerevisiae.UCSC.sacCer2
genome <- BSgenome.Scerevisiae.UCSC.sacCer2
seqlengths(genome)
genome$chrI  # same as genome[["chrI"]]

if ("AGAPS" \%in\% masknames(genome)) {

  ## Check that the assembly gaps contain only Ns:
  checkOnlyNsInGaps <- function(seq)
  {
    ## Replace all masks by the inverted AGAPS mask
    masks(seq) <- gaps(masks(seq)["AGAPS"])
    unique_letters <- uniqueLetters(seq)
    if (any(unique_letters != "N"))
        stop("assembly gaps contain more than just Ns")
  }

  ## A message will be printed each time a sequence is removed
  ## from the cache:
  options(verbose=TRUE)

  for (seqname in seqnames(genome)) {
    cat("Checking sequence", seqname, "... ")
    seq <- genome[[seqname]]
    checkOnlyNsInGaps(seq)
    cat("OK\n")
  }
}

## See the GenomeSearching vignette in the BSgenome software
## package for some examples of genome-wide motif searching using
## Biostrings and the BSgenome data packages:
if (interactive())
    vignette("GenomeSearching", package="BSgenome")
}

\keyword{package}
\keyword{data}
